@@ -6,7 +6,7 @@
  * (the "License"); you may not use this file except in compliance with
  * the License.  You may obtain a copy of the License at
  *
- *      http://www.apache.org/licenses/LICENSE-2.0
+ *      https://www.apache.org/licenses/LICENSE-2.0
  *
  * Unless required by applicable law or agreed to in writing, software
  * distributed under the License is distributed on an "AS IS" BASIS,
@@ -16,10 +16,12 @@
  */
 package org.apache.commons.jexl3.internal;
 
-import org.apache.commons.jexl3.JexlArithmetic;
 import java.util.HashSet;
+import java.util.LinkedHashSet;
 import java.util.Set;
 
+import org.apache.commons.jexl3.JexlArithmetic;
+
 /**
  * Helper class to create set literals.
  */
@@ -32,7 +34,16 @@ public class SetBuilder implements JexlArithmetic.SetBuilder {
      * @param size the expected set size
      */
     public SetBuilder(final int size) {
-        set = new HashSet<Object>(size);
+        this(size, false);
+    }
+
+    /**
+     * Creates a new builder.
+     * @param size the expected set size
+     * @param extended whether the set is extended
+     */
+    public SetBuilder(final int size, final boolean extended) {
+        set = extended? new LinkedHashSet<>(size) : new HashSet<>(size);
     }
 
     @Override
@@ -41,7 +52,7 @@ public class SetBuilder implements JexlArithmetic.SetBuilder {
     }
 
     @Override
-    public Object create() {
+    public Set<?> create() {
         return set;
     }
 }
