@@ -6,7 +6,7 @@
  * (the "License"); you may not use this file except in compliance with
  * the License.  You may obtain a copy of the License at
  *
- *      http://www.apache.org/licenses/LICENSE-2.0
+ *      https://www.apache.org/licenses/LICENSE-2.0
  *
  * Unless required by applicable law or agreed to in writing, software
  * distributed under the License is distributed on an "AS IS" BASIS,
@@ -20,4 +20,4 @@ package org.apache.commons.jexl3.parser;
  * This class only exists to prevent JJTree from generating it, since it
  * expects {@link ParserVisitor} to be an interface, not an abstract class.
  */
-class ParserDefaultVisitor { }
+final class ParserDefaultVisitor { }
