@@ -6,7 +6,7 @@
  * (the "License"); you may not use this file except in compliance with
  * the License.  You may obtain a copy of the License at
  *
- *      http://www.apache.org/licenses/LICENSE-2.0
+ *      https://www.apache.org/licenses/LICENSE-2.0
  *
  * Unless required by applicable law or agreed to in writing, software
  * distributed under the License is distributed on an "AS IS" BASIS,
@@ -28,6 +28,7 @@ import static org.junit.jupiter.api.Assertions.assertTrue;
 import static org.junit.jupiter.api.Assertions.fail;
 
 import java.io.Closeable;
+import java.io.File;
 import java.lang.reflect.Method;
 import java.math.BigDecimal;
 import java.util.Arrays;
@@ -111,7 +112,7 @@ public class Issues400Test {
     @Test
     void test402() {
         final JexlContext jc = new MapContext();
-      // @formatter:off
+        // @formatter:off
       final String[] sources = {
         "if (true) { return }",
         "if (true) { 3; return }",
@@ -140,7 +141,7 @@ public class Issues400Test {
             final String src = "var a = {'a': 1};\n" +
                 "var list = [a, a];\n" +
                 "let map1 = {:};\n" +
-                "for (var item : list) {\n" +
+                "for (let item : list) {\n" +
                 setmap +
                 "}\n " +
                 "map1";
@@ -163,26 +164,26 @@ public class Issues400Test {
         final JexlEngine jexl = new JexlBuilder().cache(64).strict(true).safe(false).create();
         Map<String, Object> a = Collections.singletonMap("b", 42);
         // access is constant
-        for (final String src : new String[] { "a.b", "a?.b", "a['b']", "a?['b']", "a?.`b`" }) {
+        for (final String src : new String[]{"a.b", "a?.b", "a['b']", "a?['b']", "a?.`b`"}) {
             run404(jexl, src, a);
             run404(jexl, src + ";", a);
         }
         // access is variable
-        for (final String src : new String[] { "a[b]", "a?[b]", "a?.`${b}`" }) {
+        for (final String src : new String[]{"a[b]", "a?[b]", "a?.`${b}`"}) {
             run404(jexl, src, a, "b");
             run404(jexl, src + ";", a, "b");
         }
         // add a 3rd access
         final Map<String, Object> b = Collections.singletonMap("c", 42);
         a = Collections.singletonMap("b", b);
-        for (final String src : new String[] { "a[b].c", "a?[b]?['c']", "a?.`${b}`.c" }) {
+        for (final String src : new String[]{"a[b].c", "a?[b]?['c']", "a?.`${b}`.c"}) {
             run404(jexl, src, a, "b");
         }
     }
 
     @Test
     void test404b() {
-      // @formatter:off
+        // @formatter:off
       final JexlEngine jexl = new JexlBuilder()
           .cache(64)
           .strict(true)
@@ -192,7 +193,7 @@ public class Issues400Test {
         final Map<String, Object> b = Collections.singletonMap("c", 42);
         final Map<String, Object> a = Collections.singletonMap("b", b);
         JexlScript script;
-        Object result = -42;
+        Object result;
         script = jexl.createScript("a?['B']?['C']", "a");
         result = script.execute(null, a);
         assertEquals(script.getSourceText(), script.getParsedText());
@@ -212,13 +213,13 @@ public class Issues400Test {
         // can still do ternary, note the space between ? and [
         script = jexl.createScript("a? ['B']:['C']", "a");
         result = script.execute(null, a);
-        assertArrayEquals(new String[] { "B" }, (String[]) result);
+        assertArrayEquals(new String[]{"B"}, (String[]) result);
         script = jexl.createScript("a?['b'] ?: ['C']", "a");
         result = script.execute(null, a);
         assertEquals(b, result);
         script = jexl.createScript("a?['B'] ?: ['C']", "a");
         result = script.execute(null, a);
-        assertArrayEquals(new String[] { "C" }, (String[]) result);
+        assertArrayEquals(new String[]{"C"}, (String[]) result);
     }
 
     @Test
@@ -251,7 +252,7 @@ public class Issues400Test {
         final JexlScript script0 = jexl.createScript(src0, "x");
         final String src1 = "join(x, '*')";
         final JexlScript script1 = jexl.createScript(src1, "x");
-        for (final Object x : Arrays.asList(Arrays.asList(1, 2, 3, 4), new int[] { 1, 2, 3, 4 })) {
+        for (final Object x : Arrays.asList(Arrays.asList(1, 2, 3, 4), new int[]{1, 2, 3, 4})) {
             Object result = script0.execute(context, x);
             assertEquals("1*2*3*4", result, src0);
             result = script1.execute(context, x);
@@ -271,7 +272,7 @@ public class Issues400Test {
         Number result = (Number) script.execute(null, 99.0d, 7.82d);
         assertEquals(0d, result.doubleValue(), 8.e-15);
         // using BigdDecimal, more precise, still not zero
-        result = (Number) script.execute(null, new BigDecimal(99.0d), new BigDecimal(7.82d));
+        result = (Number) script.execute(null, new BigDecimal("99.0"), new BigDecimal("7.82"));
         assertEquals(0d, result.doubleValue(), 3.e-32);
     }
 
@@ -334,7 +335,9 @@ public class Issues400Test {
     void test413d() {
         final JexlBuilder builder = new JexlBuilder().features(new JexlFeatures().constCapture(true));
         final JexlEngine jexl = builder.create();
-        final JexlException.Parsing xparse = assertThrows(JexlException.Parsing.class, () -> jexl.createScript("var c = 42; var f = y -> c += y; f(z)", "z"),
+        final JexlException.Parsing xparse = assertThrows(
+                JexlException.Parsing.class,
+                () -> jexl.createScript("var c = 42; var f = y -> c += y; f(z)", "z"),
                 "c should be const");
         assertTrue(xparse.getMessage().contains("const"));
     }
@@ -462,50 +465,41 @@ public class Issues400Test {
 
     @Test
     void test429a() {
-        MapContext ctxt = new MapContext();
-        //ctxt.set("b", 1);
-        JexlFeatures features = JexlFeatures.createDefault();
-        final JexlEngine jexl = new JexlBuilder()
-                .features(features)
-                .safe(false).strict(true).silent(false).create();
-        JexlScript f = jexl.createScript("x -> x");
+        final MapContext ctxt = new MapContext();
+        final JexlFeatures features = JexlFeatures.createDefault();
+        final JexlEngine jexl = new JexlBuilder().features(features).safe(false).strict(true).silent(false).create();
+        final JexlScript f = jexl.createScript("x -> x");
         ctxt.set("f", f);
-        String src = "#pragma jexl.namespace.b "+Ns429.class.getName()  +"\n"
-                +"b ? b : f(2);";
+        String src = "#pragma jexl.namespace.b " + Ns429.class.getName() + "\n" + "b ? b : f(2);";
         JexlScript script = jexl.createScript(src, "b");
         assertEquals(1, (int) script.execute(ctxt, 1));
 
-        src = "#pragma jexl.namespace.b "+Ns429.class.getName()  +"\n"
-                +"b ? b:f(2) : 1;";
+        src = "#pragma jexl.namespace.b " + Ns429.class.getName() + "\n" + "b ? b:f(2) : 1;";
         script = jexl.createScript(src, "b");
         assertEquals(20042, (int) script.execute(ctxt, 1));
     }
 
     @Test
     void test429b() {
-        MapContext ctxt = new MapContext();
+        final MapContext ctxt = new MapContext();
         ctxt.set("b", 1);
-        JexlFeatures features = JexlFeatures.createDefault();
+        final JexlFeatures features = JexlFeatures.createDefault();
         features.namespaceIdentifier(true);
-        final JexlEngine jexl = new JexlBuilder()
-                .features(features)
-                .safe(false).strict(true).silent(false).create();
-        JexlScript f = jexl.createScript("x -> x");
+        final JexlEngine jexl = new JexlBuilder().features(features).safe(false).strict(true).silent(false).create();
+        final JexlScript f = jexl.createScript("x -> x");
         ctxt.set("f", f);
-        String src = "#pragma jexl.namespace.b "+Ns429.class.getName()  +"\n"
-                +"b ? b : f(2);";
+        String src = "#pragma jexl.namespace.b " + Ns429.class.getName() + "\n" + "b ? b : f(2);";
         JexlScript script = jexl.createScript(src);
         assertEquals(1, (int) script.execute(ctxt));
 
-        src = "#pragma jexl.namespace.b "+Ns429.class.getName()  +"\n"
-                +"b ? b:f(2) : 1;";
+        src = "#pragma jexl.namespace.b " + Ns429.class.getName() + "\n" + "b ? b:f(2) : 1;";
         script = jexl.createScript(src);
         assertEquals(20042, (int) script.execute(ctxt));
     }
 
     @Test
     void test431a() {
-        JexlEngine jexl = new JexlBuilder().create();
+        final JexlEngine jexl = new JexlBuilder().create();
         final String src = "let x = 0; try { x += 19 } catch (let error) { return 169 } try { x += 23 } catch (let error) { return 169 }";
         final JexlScript script = jexl.createScript(src);
         assertNotNull(script);
@@ -519,7 +513,7 @@ public class Issues400Test {
 
     @Test
     void test431b() {
-        JexlEngine jexl = new JexlBuilder().create();
+        final JexlEngine jexl = new JexlBuilder().create();
         final String src = "let x = 0; try(let error) { x += 19 } catch (let error) { return 169 } try { x += 23 } catch (let error) { return 169 }";
         final JexlScript script = jexl.createScript(src);
         assertNotNull(script);
@@ -529,46 +523,46 @@ public class Issues400Test {
 
     @Test
     void test431c() {
-        JexlEngine jexl = new JexlBuilder().create();
+        final JexlEngine jexl = new JexlBuilder().create();
         final String src = "let xx = 0; try { xx += 19 } catch (let xx) { return 169 }";
         try {
             final JexlScript script = jexl.createScript(src);
             fail("xx is already defined in scope");
-        } catch(JexlException.Parsing parsing) {
+        } catch (final JexlException.Parsing parsing) {
             assertTrue(parsing.getDetail().contains("xx"));
         }
     }
 
     @Test
     void test433() {
-        JexlEngine jexl = new JexlBuilder().create();
+        final JexlEngine jexl = new JexlBuilder().create();
         final String src = "let condition = true; if (condition) { return; }";
         final JexlScript script = jexl.createScript(src);
         assertNotNull(script);
-        Object result = script.execute(null);
+        final Object result = script.execute(null);
         assertNull(result);
-        Debugger debugger = new Debugger();
+        final Debugger debugger = new Debugger();
         assertTrue(debugger.debug(script));
-        String dbgStr = debugger.toString();
+        final String dbgStr = debugger.toString();
         assertTrue(JexlTestCase.equalsIgnoreWhiteSpace(src, dbgStr));
     }
 
     @Test
     void test434() {
-        JexlEngine jexl = new JexlBuilder().safe(false).strict(true).create();
+        final JexlEngine jexl = new JexlBuilder().safe(false).strict(true).create();
         final String src = "let foo = null; let value = foo?[bar]";
         final JexlScript script = jexl.createScript(src);
         assertNotNull(script);
         final Object result = script.execute(null);
         assertNull(result);
-
     }
 
     public static class Arithmetic435 extends JexlArithmetic {
-        public Arithmetic435(boolean strict) {
+        public Arithmetic435(final boolean strict) {
             super(strict);
         }
-        public Object empty(String type) {
+
+        public Object empty(final String type) {
             if ("list".equals(type)) {
                 return Collections.emptyList();
             }
@@ -578,8 +572,8 @@ public class Issues400Test {
 
     @Test
     void test435() {
-        JexlArithmetic arithmetic = new Arithmetic435(true);
-        JexlEngine jexl = new JexlBuilder().arithmetic(arithmetic).create();
+        final JexlArithmetic arithmetic = new Arithmetic435(true);
+        final JexlEngine jexl = new JexlBuilder().arithmetic(arithmetic).create();
         final String src = "empty('list')";
         final JexlScript script = jexl.createScript(src);
         assertNotNull(script);
@@ -589,42 +583,85 @@ public class Issues400Test {
 
     @Test
     void test436a() {
-        String[] srcs = {"let i = null; ++i", "let i; ++i;", "let i; i--;",  "let i; i++;"};
+        final String[] srcs = {"let i = null; ++i", "let i; ++i;", "let i; i--;", "let i; i++;"};
         run436(null, srcs);
     }
 
     @Test
     void test436b() {
-        String[] srcs = {"var i = null; ++i", "var i; ++i;", "var i; i--;",  "var i; i++;"};
+        final String[] srcs = {"var i = null; ++i", "var i; ++i;", "var i; i--;", "var i; i++;"};
         run436(null, srcs);
     }
 
     @Test
     void test436c() {
-        JexlContext ctxt = new MapContext();
+        final JexlContext ctxt = new MapContext();
         ctxt.set("i", null);
-        String[] srcs = {"++i", "++i;", "i--;",  "i++;"};
+        final String[] srcs = {"++i", "++i;", "i--;", "i++;"};
         run436(null, srcs);
     }
 
-    void run436(JexlContext ctxt, String[] srcs) {
+    void run436(final JexlContext ctxt, final String[] srcs) {
         final JexlEngine jexl = new JexlBuilder().create();
-        for(String src : srcs) {
-            JexlScript script = jexl.createScript(src);
+        for (final String src : srcs) {
+            final JexlScript script = jexl.createScript(src);
             assertThrows(JexlException.Operator.class, () -> script.execute(ctxt));
         }
     }
 
-    /** The set of characters that may be followed by a '='.*/
+    @Test
+    void test437a() {
+        final JexlEngine jexl = new JexlBuilder().create();
+        final String src = "let values = [...]\n"
+                + "function append(const value) {\n"
+                + "  values.add(value)\n"
+                + "}\n"
+                + "\n"
+                + "append(1)\n"
+                + "append(2)\n"
+                + "return values ";
+        final JexlScript script = jexl.createScript(src);
+        assertNotNull(script);
+        final Object result = script.execute(null);
+        assertInstanceOf(List.class, result);
+        final List<?> values = (List<?>) result;
+        assertEquals(2, values.size());
+    }
+
+    @Test
+    void test437b() {
+        final JexlFeatures features = JexlFeatures.createDefault().ambiguousStatement(true);
+        assertTrue(features.supportsAmbiguousStatement());
+        final JexlEngine jexl = new JexlBuilder().features(features).create();
+        final String src = "let values = [...]"
+                + "function append(const value) {"
+                + "  values.add(value)"
+                + "}"
+                + "append(1)"
+                + "append(2)"
+                + "return values ";
+        final JexlScript script = jexl.createScript(src);
+        assertNotNull(script);
+        final Object result = script.execute(null);
+        assertInstanceOf(List.class, result);
+        final List<?> values = (List<?>) result;
+        assertEquals(2, values.size());
+    }
+
+    /**
+     * The set of characters that may be followed by a '='.
+     */
     static final char[] EQ_FRIEND;
+
     static {
-        char[] eq = {'!', ':', '<', '>', '^', '|', '&', '+', '-', '/', '*', '~', '='};
+        final char[] eq = {'!', ':', '<', '>', '^', '|', '&', '+', '-', '/', '*', '~', '='};
         Arrays.sort(eq);
         EQ_FRIEND = eq;
     }
 
     /**
      * Transcodes a SQL-inspired expression to a JEXL expression.
+     *
      * @param expr the expression to transcode
      * @return the resulting expression
      */
@@ -633,7 +670,7 @@ public class Issues400Test {
         final int end = expr.length();
         char previous = 0;
         for (int i = 0; i < end; ++i) {
-            char c = expr.charAt(i);
+            final char c = expr.charAt(i);
             if (previous == '<') {
                 // previous char a '<' now followed by '>'
                 if (c == '>') {
@@ -641,9 +678,8 @@ public class Issues400Test {
                     strb.append("!=");
                     previous = c;
                     continue;
-                } else {
-                    strb.append('<');
                 }
+                strb.append('<');
             }
             if (c != '<') {
                 if (c == '=') {
@@ -685,41 +721,41 @@ public class Issues400Test {
         }
 
         @Override
-        public ASTJexlScript parse(JexlInfo info, JexlFeatures features, String src, Scope scope) {
+        public ASTJexlScript parse(final JexlInfo info, final JexlFeatures features, final String src, final Scope scope) {
             return parser.parse(info, features, transcodeSQLExpr(src), scope);
         }
+
+        @Override
+        public ASTJexlScript jxltParse(final JexlInfo info, final JexlFeatures features, final String src, final Scope scope) {
+            return new Parser(parser).parse(info, features, transcodeSQLExpr(src), scope);
+        }
     }
 
 
     @Test
     void testSQLTranspose() {
-        String[] e = { "a<>b", "a = 2", "a.b.c <> '1<>0'" };
-        String[] j = { "a!=b", "a == 2", "a.b.c != '1<>0'" };
-        for(int i = 0; i < e.length; ++i) {
-            String je = transcodeSQLExpr(e[i]);
+        final String[] e = {"a<>b", "a = 2", "a.b.c <> '1<>0'"};
+        final String[] j = {"a!=b", "a == 2", "a.b.c != '1<>0'"};
+        for (int i = 0; i < e.length; ++i) {
+            final String je = transcodeSQLExpr(e[i]);
             Assertions.assertEquals(j[i], je);
         }
     }
 
     @Test
     void testSQLNoChange() {
-        String[] e = { "a <= 2", "a >= 2", "a := 2", "a + 3 << 4 > 5",  };
-        for(int i = 0; i < e.length; ++i) {
-            String je = transcodeSQLExpr(e[i]);
-            Assertions.assertEquals(e[i], je);
+        final String[] e = {"a <= 2", "a >= 2", "a := 2", "a + 3 << 4 > 5",};
+        for (final String element : e) {
+            final String je = transcodeSQLExpr(element);
+            Assertions.assertEquals(element, je);
         }
     }
 
     @Test
     void test438() {// no local, no lambda, no loops, no-side effects
-        final JexlFeatures f = new JexlFeatures()
-                .localVar(false)
-                .lambda(false)
-                .loops(false)
-                .sideEffect(false)
-                .sideEffectGlobal(false);
-        JexlBuilder builder = new JexlBuilder().parserFactory(SQLParser::new).cache(32).features(f);
-        JexlEngine sqle = builder.create();
+        final JexlFeatures f = new JexlFeatures().localVar(false).lambda(false).loops(false).sideEffect(false).sideEffectGlobal(false);
+        final JexlBuilder builder = new JexlBuilder().parserFactory(SQLParser::new).cache(32).features(f);
+        final JexlEngine sqle = builder.create();
         Assertions.assertTrue((boolean) sqle.createScript("a <> 25", "a").execute(null, 24));
         Assertions.assertFalse((boolean) sqle.createScript("a <> 25", "a").execute(null, 25));
         Assertions.assertFalse((boolean) sqle.createScript("a = 25", "a").execute(null, 24));
@@ -727,4 +763,59 @@ public class Issues400Test {
         Assertions.assertTrue((boolean) sqle.createScript("a = 25", "a").execute(null, 25));
         Assertions.assertFalse((boolean) sqle.createScript("a != 25", "a").execute(null, 25));
     }
+
+    @Test
+    void testIssue441() {
+        final JexlEngine jexl = new JexlBuilder().create();
+        String ctl = "\nab\nc`d\n";
+        final JexlExpression e = jexl.createExpression("`\nab\nc\\`d\n`");
+        Object o = e.evaluate(null);
+        Assertions.assertEquals(ctl, o);
+
+        final JexlContext context = new MapContext();
+        context.set("name", "Hello");
+        final String code = "return `${name + '\\n' + name}`;";
+        final JexlScript script = jexl.createScript(code);
+        o = script.execute(context);
+        ctl = "Hello\nHello";
+        Assertions.assertEquals(ctl, o);
+    }
+
+    @Test
+    void testIssue442() {
+        final JexlEngine jexl = new JexlBuilder().create();
+        final JexlContext context = new MapContext();
+        final String code = "var x = 'hello';\n" +
+                "function test(z) {\n" +
+                //"x + ' ' + z\n"+
+                "`${x} ${z}`;\n" +
+                "}\n" +
+                "test('world');";
+        final JexlScript script = jexl.createScript(code);
+        final Object result = script.execute(context);
+        Assertions.assertEquals("hello world", result);
+    }
+
+
+    @Test
+    void testIssue447() {
+        final JexlEngine jexl = new JexlBuilder().create();
+        final String src = "const c = `${a}\n?= ${b}`; function foo(const left, const right) { `${left}\n?== ${right}` } c+foo(a, b)";
+        final JexlScript script = jexl.createScript(src, "a", "b");
+        final Object result = script.execute(null, "a", "b");
+        Assertions.assertEquals("a\n?= ba\n?== b", result);
+
+        final String TEST447 = "src/test/scripts/test447.jexl";
+        final File src447 = new File(TEST447);
+        final JexlScript script447 = jexl.createScript(src447);
+        final Object result447 = script447.execute(null);
+        Assertions.assertInstanceOf(List.class, result447);
+        @SuppressWarnings("unchecked")
+        final List<Boolean> list = (List<Boolean>) result447;
+        for (final Boolean item : list) {
+            Assertions.assertTrue(item);
+        }
+    }
+
 }
+
